==> haskell-fsnotify0.3-0.3.0.1-65-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-fsnotify0.3.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 fsnotify
version:              0.3.0.1
visibility:           public
id:                   fsnotify-0.3.0.1-4H7RY8Gc44N3EAdJlixahB
key:                  fsnotify-0.3.0.1-4H7RY8Gc44N3EAdJlixahB
license:              BSD-3-Clause
maintainer:           Tom McLaughlin <tom@codedown.io>
author:               Mark Dittmer <mark.s.dittmer@gmail.com>, Niklas Broberg
homepage:             https://github.com/haskell-fswatch/hfsnotify
synopsis:             Cross platform library for file change notification.
description:
    Cross platform library for file creation, modification,
    and deletion notification. This library builds upon
    existing libraries for platform-specific Windows, Mac,
    and Linux filesystem event notification.

category:             Filesystem
abi:                  4b04bbac99d0d74a7f555642cba1c4e8
exposed:              True
exposed-modules:      System.FSNotify System.FSNotify.Devel
hidden-modules:
    System.FSNotify.Listener System.FSNotify.Path
    System.FSNotify.Polling System.FSNotify.Types System.FSNotify.Linux

import-dirs:          /usr/lib/ghc-9.2.8/site-local/fsnotify-0.3.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/fsnotify-0.3.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fsnotify0.3
hs-libraries:         HSfsnotify-0.3.0.1-4H7RY8Gc44N3EAdJlixahB
depends:
    async-2.2.5-EP8h1wWlEwVFRsNBoUfgIV base-4.16.4.0
    bytestring-0.11.4.0 containers-0.6.5.1 directory-1.3.6.2
    filepath-1.4.2.2 hinotify-0.4.1-AqMgcp4xYVwFxTsh4ij9fb
    shelly-1.10.0.1-HtCpYVbOUsrD6o8HdlSEh8 text-1.2.5.0 time-1.11.1.1
    unix-2.7.2.2 unix-compat-0.7.1-J1Kwi1oG5prLsIuHiVwF3d

haddock-interfaces:   /usr/share/doc/haskell-fsnotify0.3/html/fsnotify.haddock
haddock-html:         /usr/share/doc/haskell-fsnotify0.3/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fsnotify0.3-0.3.0.1-76.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-fsnotify0.3.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 fsnotify
version:              0.3.0.1
visibility:           public
id:                   fsnotify-0.3.0.1-FBOhuDoudLvFRntVVxT7Bg
key:                  fsnotify-0.3.0.1-FBOhuDoudLvFRntVVxT7Bg
license:              BSD-3-Clause
maintainer:           Tom McLaughlin <tom@codedown.io>
author:               Mark Dittmer <mark.s.dittmer@gmail.com>, Niklas Broberg
homepage:             https://github.com/haskell-fswatch/hfsnotify
synopsis:             Cross platform library for file change notification.
description:
    Cross platform library for file creation, modification,
    and deletion notification. This library builds upon
    existing libraries for platform-specific Windows, Mac,
    and Linux filesystem event notification.

category:             Filesystem
abi:                  08734774de1eeb5fa442fe440caf183f
exposed:              True
exposed-modules:      System.FSNotify System.FSNotify.Devel
hidden-modules:
    System.FSNotify.Listener System.FSNotify.Path
    System.FSNotify.Polling System.FSNotify.Types System.FSNotify.Linux

import-dirs:          /usr/lib/ghc-9.2.8/site-local/fsnotify-0.3.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/fsnotify-0.3.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fsnotify0.3
hs-libraries:         HSfsnotify-0.3.0.1-FBOhuDoudLvFRntVVxT7Bg
depends:
    async-2.2.5-Hxx4nU8aNwh7V1GfZTZX85 base-4.16.4.0
    bytestring-0.11.4.0 containers-0.6.5.1 directory-1.3.6.2
    filepath-1.4.2.2 hinotify-0.4.1-BsxYww9KyhD2ePNbbxqnh
    shelly-1.10.0.1-CiXfDCQhV0r1f29uGsfVte text-1.2.5.0 time-1.11.1.1
    unix-2.7.2.2 unix-compat-0.7.2-3S8nQVag41zGjHM5MpRJPG

haddock-interfaces:   /usr/share/doc/haskell-fsnotify0.3/html/fsnotify.haddock
haddock-html:         /usr/share/doc/haskell-fsnotify0.3/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
